@@ -29,6 +29,7 @@
 #include "engines/svtplay-dl.h"
 #include "engines/you-get.h"
 #include "engines/deno.h"
+#include "engines/quickjs.h"
 #include "engines/getsauce.h"
 
 #include "reportFinished.h"
@@ -290,6 +291,24 @@ util::result< engines::engine > engines::getEngineByPath( const QString& e ) con
 	}
 }
 
+util::result_ref< const engines::engine& > engines::getCompleteEngineByPath( const QString& e ) const
+{
+	auto m = this->getEngineByPath( e ) ;
+
+	if( m && m->valid() ){
+
+		for( const auto& it : this->getEngines() ){
+
+			if( m->name() == it.name() ){
+
+				return it ;
+			}
+		}
+	}
+
+	return {} ;
+}
+
 QStringList engines::engine::dumpJsonArguments( engines::engine::tab tab ) const
 {
 	if( this->name() == "gallery-dl" ){
@@ -444,12 +463,14 @@ void engines::updateEngines( bool addAll,int id )
 
 			it.setBackend< deno >( engines ) ;
 
+		}else if( name.contains( "quickjs" ) ){
+
+			it.setBackend< quickjs >( engines ) ;
+
 		}else if( name.contains( "getsauce" ) ){
 
-			it.setBackend< getsauce >( engines,m_settings.downloadFolder() ) ;
-
-		}else if( it.mainEngine() ){
-
+			it.setBackend< getsauce >( engines,m_settings.downloadFolder() ) ;			
+		}else{
 			it.setBackend< generic >( engines ) ;
 		}
 	}
@@ -548,7 +569,7 @@ QString engines::findExecutable( const QString& exeName ) const
 	if( utility::platformIsLikeWindows() ){
 
 		auto paths = this->processEnvironment().value( "PATH" ).split( ';' ) ;
-		
+
 		auto m = this->findExecutable( exeName,paths,info ) ;
 
 		if( m.isEmpty() && !exeName.endsWith( ".exe" ) ){
@@ -559,7 +580,7 @@ QString engines::findExecutable( const QString& exeName ) const
 		return m ;
 	}else{
 		auto paths = this->processEnvironment().value( "PATH" ).split( ':' ) ;
-		
+
 		return this->findExecutable( exeName,paths,info ) ;
 	}
 }
@@ -617,9 +638,9 @@ QString engines::addEngine( const QByteArray& data,const QString& path,int id )
 
 void engines::removeEngine( const QString& e,int id )
 {
-	const auto& engine = this->getEngineByPath( e ) ;
+	const auto& engine = this->getCompleteEngineByPath( e ) ;
 
-	if( engine && engine->valid() ){
+	if( engine ){
 
 		utility::removeFile( m_enginePaths.enginePath( e ) ) ;
 
@@ -637,7 +658,7 @@ void engines::removeEngine( const QString& e,int id )
 
 			if( exe.startsWith( binPath ) && QFile::exists( exe ) ){
 
-				utility::removeFile( exe ) ;
+				engine->removeFiles( { exe },binPath ) ;
 			}
 		}
 
@@ -683,9 +704,10 @@ engines::engine::engine( const engines& engines,
 	m_line( line ),
 	m_position( position ),
 	m_valid( true ),
-	m_mainEngine( false ),
+	m_supportingEngine( true ),
 	m_versionArgument( versionArgument ),
 	m_name( name ),
+	m_likeYtDlp( false ),
 	m_commandName( utility::platformIsLikeWindows() ? name + ".exe" : name )
 {
 	auto m = engines.findExecutable( m_commandName ) ;
@@ -722,11 +744,17 @@ QStringList engines::engine::toStringList( const QJsonValue& value,bool protectS
 
 void engines::engine::updateOptions()
 {
-	auto m = this->toStringList( m_jsonObject.value( "ExtraArguments" ) ) ;
+	if( utility::platformIsWindows7() ){
 
-	if( m.size() && m.last() != "ejs:github" ){
+		m_extraArguments = this->toStringList( m_jsonObject.value( "ExtraArgumentsWin7" ) ) ;
 
-		m_extraArguments = m ;
+	}else if( utility::platformisFlatPak() && this->likeYtDlp() ){
+
+		m_extraArguments.append( "--no-js-runtimes" ) ;
+		m_extraArguments.append( "--js-runtimes" ) ;
+		m_extraArguments.append( "quickjs" ) ;
+	}else{
+		m_extraArguments = this->toStringList( m_jsonObject.value( "ExtraArguments" ) ) ;
 	}
 
 	m_controlStructure                = m_jsonObject.value( "ControlJsonStructure" ).toObject() ;
@@ -867,7 +895,6 @@ engines::engine::engine( Logger& logger,
 	m_position( m_jsonObject.value( "VersionStringPosition" ).toInt() ),
 	m_valid( true ),
 	m_autoUpdate( m_jsonObject.value( "AutoUpdate" ).toBool( true ) ),
-	m_mainEngine( true ),
 	m_archiveContainsFolder( m_jsonObject.value( "ArchiveContainsFolder" ).toBool() ),
 	m_versionArgument( m_jsonObject.value( "VersionArgument" ).toString() ),
 	m_name( m_jsonObject.value( "Name" ).toString() ),
@@ -886,6 +913,13 @@ engines::engine::engine( Logger& logger,
 		}
 	}
 
+	if( m_name == "deno" || m_name == "quickjs" ){
+
+		m_supportingEngine = true ;
+	}else{
+		m_supportingEngine = false ;
+	}
+
 	if( m_name == "svtplay-dl" ){
 
 		m_archiveContainsFolder = utility::platformIsWindows() ;
@@ -905,7 +939,7 @@ engines::engine::engine( Logger& logger,
 
 	auto m = cmd.isUndefined() ? this->getLegacyCommands() : this->getCommands( cmd.toObject() ) ;
 
-	if( utility::platformIsWindows7() && m_likeYtDlp ){
+	if( utility::platformIsWindows7() && this->likeYtDlp() ){
 
 		if( cmd.isUndefined() ){
 
@@ -1138,6 +1172,14 @@ QString engines::engine::versionString( const QString& data ) const
 	return {} ;
 }
 
+bool engines::engine::validDownloadUrl() const
+{
+	auto a = "https://api.github.com" ;
+	auto b = "https://bellard.org/quickjs/binary_releases" ;
+
+	return m_downloadUrl.startsWith( a ) || m_downloadUrl.startsWith( b ) ;
+}
+
 void engines::engine::setPermissions( const QString& e ) const
 {
 	utility::setPermissions( e ) ;
@@ -1525,11 +1567,6 @@ bool engines::engine::baseEngine::updateVersionInfo()
 	return false ;
 }
 
-bool engines::engine::baseEngine::supportingEngine()
-{
-	return false ;
-}
-
 QByteArray engines::engine::baseEngine::parseError( const QByteArray& )
 {
 	return {} ;
@@ -1609,10 +1646,32 @@ void engines::engine::baseEngine::updateEnginePaths( const Context&,QString&,QSt
 {
 }
 
+QString engines::engine::baseEngine::parseVersionInfo( const utils::qprocess::outPut& r )
+{
+	return utility::parseVersionInfo( r ) ;
+}
+
 void engines::engine::baseEngine::updateLocalOptions( QStringList& )
 {
 }
 
+std::vector< engines::engine::baseEngine::removeFilesStatus > engines::engine::baseEngine::removeFiles( const QStringList& e,const QString& )
+{
+	std::vector< engines::engine::baseEngine::removeFilesStatus > s ;
+
+	for( const auto& it : e ){
+
+		auto m = utility::removeFile( it ) ;
+
+		if( !m.isEmpty() ){
+
+			s.emplace_back( it,m ) ;
+		}
+	}
+
+	return s ;
+}
+
 engines::engine::baseEngine::optionsEnvironment engines::engine::baseEngine::setProxySetting( QStringList&,const QString& )
 {
 	return {} ;
@@ -2340,12 +2399,24 @@ engines::configDefaultEngine::configDefaultEngine( Logger&logger,const enginePat
 	m_configFileName( m_name + ".json" )
 {
 	yt_dlp::init( this->name(),this->configFileName(),logger,enginePath ) ;
-	deno::init( "deno","deno.json",logger,enginePath ) ;
 
 	if( utility::platformIsWindows() ){
 
 		aria2c::init( "aria2c","aria2c.json",logger,enginePath ) ;
 		wget::init( "wget","wget.json",logger,enginePath ) ;
+
+		if( utility::platformIsWindows7() ){
+
+			quickjs::init( "quickjs","quickjs.json",logger,enginePath ) ;
+		}else{
+			deno::init( "deno","deno.json",logger,enginePath ) ;
+		}
+
+	}else if( utility::platformisFlatPak() ){
+
+		quickjs::init( "quickjs","quickjs.json",logger,enginePath ) ;
+	}else{
+		deno::init( "deno","deno.json",logger,enginePath ) ;
 	}
 }
 
