@@ -734,8 +734,6 @@ public:
 
 			virtual bool updateVersionInfo() ;
 
-			virtual bool supportingEngine() ;
-
 			virtual QByteArray parseError( const QByteArray& ) ;
 
 			virtual void setTextEncondig( const QString&,QStringList& opts ) ;
@@ -758,8 +756,36 @@ public:
 
 			virtual void updateEnginePaths( const Context&,QString& filePath,QString& exeBinPath,QString& exeFolderPath ) ;
 
+			virtual QString parseVersionInfo( const utils::qprocess::outPut& ) ;
+
 			virtual void updateLocalOptions( QStringList& ) ;
 
+			class removeFilesStatus
+			{
+			public:
+				removeFilesStatus( QString s,QString e ) :
+					m_src( std::move( s ) ),m_err( std::move( e ) )
+				{
+				}
+				removeFilesStatus()
+				{
+				}
+				const QString& src() const
+				{
+					return m_src ;
+				}
+				const QString& err() const
+				{
+					return m_err ;
+				}
+			private:
+				QString m_src ;
+				QString m_err ;
+			} ;
+
+			virtual std::vector< engines::engine::baseEngine::removeFilesStatus >
+			removeFiles( const QStringList&,const QString& ) ;
+
 			class optionsEnvironment
 			{
 			public:
@@ -1072,10 +1098,7 @@ public:
 		{
 			return m_downloadUrl ;
 		}
-		bool validDownloadUrl() const
-		{
-			return m_downloadUrl.startsWith( "https://api.github.com" ) ;
-		}
+		bool validDownloadUrl() const ;
 		bool supportsTextEnconding() const
 		{
 			return !m_encodingArgument.isEmpty() ;
@@ -1199,17 +1222,21 @@ public:
 		{
 			return m_engine->horizontalHeaderLabels() ;
 		}
-		virtual QJsonObject parseJson( const QString& url,const QByteArray& e ) const
+		QJsonObject parseJson( const QString& url,const QByteArray& e ) const
 		{
 			return m_engine->parseJson( url,e ) ;
 		}
+		QString parseVersionInfo( const utils::qprocess::outPut& e ) const
+		{
+			return m_engine->parseVersionInfo( e ) ;
+		}
 		void openLocalFile( const engines::engine::baseEngine::localFile& s ) const
 		{
 			m_engine->openLocalFile( s ) ;
 		}
-		bool supportingEngine() const
+		std::vector< engines::engine::baseEngine::removeFilesStatus > removeFiles( const QStringList& e,const QString& s ) const
 		{
-			return m_engine->supportingEngine() ;
+			return m_engine->removeFiles( e,s ) ;
 		}
 		QByteArray parseError( const QByteArray& e ) const
 		{
@@ -1332,9 +1359,9 @@ public:
 		{
 			return m_autoUpdate ;
 		}
-		bool mainEngine() const
+		bool supportingEngine() const
 		{
-			return m_mainEngine ;
+			return m_supportingEngine ;
 		}
 		bool replaceOutputWithProgressReport() const
 		{
@@ -1381,7 +1408,7 @@ public:
 		bool m_valid ;
 		bool m_autoUpdate ;
 		bool m_canDownloadPlaylist ;
-		bool m_mainEngine ;
+		bool m_supportingEngine ;
 		bool m_archiveContainsFolder = false ;
 		bool m_replaceOutputWithProgressReport ;
 		mutable bool m_broken = false ;
@@ -1544,6 +1571,7 @@ public:
 private:
 	void updateEngines( bool,int ) ;
 	util::result< engines::engine > getEngineByPath( const QString& ) const ;
+	util::result_ref< const engines::engine& > getCompleteEngineByPath( const QString& ) const ;
 	void engineAdd( const QString&,util::result< engines::engine >,int ) ;
 	QString findExecutable( const QString&,const QStringList&,QFileInfo& ) const ;
 	QProcessEnvironment getEnvPaths() const ;
