@@ -113,6 +113,11 @@ engines::engine::baseEngine::DataFilter lux::Filter( int id )
 	return { util::types::type_identity< lux::lux_dlFilter >(),m_engine,id,m_downloadFolder.toUtf8() } ;
 }
 
+engines::engine::baseEngine::optionsEnvironment lux::setProxySetting( QStringList&,const QString& e )
+{
+	return { "HTTPS_PROXY",e } ;
+}
+
 std::vector<engines::engine::baseEngine::mediaInfo> lux::mediaProperties( Logger& l,const QByteArray& e )
 {
 	QJsonParseError err ;
@@ -189,7 +194,7 @@ bool lux::foundNetworkUrl( const QString& s )
 {
 	if( utility::platformIsWindows() ){
 
-		if( utility::platformIs32Bit() ){
+		if( utility::CPU().x86_32() ){
 
 			return s.contains( "Windows_i386" ) ;
 		}else{
@@ -198,7 +203,7 @@ bool lux::foundNetworkUrl( const QString& s )
 
 	}else if( utility::platformIsLinux() ){
 
-		if( utility::platformIs32Bit() ){
+		if( utility::CPU().x86_32() ){
 
 			return s.contains( "Linux_i386" ) ;
 		}else{
@@ -225,9 +230,11 @@ static QByteArray _hash( const QString& r )
 	return hash.result().toHex().mid( 0,8 ) ;
 }
 
-void lux::updateDownLoadCmdOptions( const engines::engine::baseEngine::updateOpts& s,bool e )
+void lux::updateDownLoadCmdOptions( const engines::engine::baseEngine::updateOpts& s,
+				    bool e,
+				    const QStringList& extraOpts )
 {
-	engines::engine::baseEngine::updateDownLoadCmdOptions( s,e ) ;
+	engines::engine::baseEngine::updateDownLoadCmdOptions( s,e,extraOpts ) ;
 
 	for( int m = 0 ; m < s.ourOptions.size() ; m++ ){
 
