@@ -375,11 +375,13 @@ void svtplay_dl::updateOutPutChannel( QProcess::ProcessChannel& s ) const
 	s = QProcess::ProcessChannel::StandardError ;
 }
 
-void svtplay_dl::updateDownLoadCmdOptions( const engines::engine::baseEngine::updateOpts& e,bool s )
+void svtplay_dl::updateDownLoadCmdOptions( const engines::engine::baseEngine::updateOpts& e,
+					   bool s,
+					   const QStringList& m )
 {
 	e.ourOptions.append( "--verbose" ) ;
 
-	engines::engine::baseEngine::updateDownLoadCmdOptions( e,s ) ;
+	engines::engine::baseEngine::updateDownLoadCmdOptions( e,s,m ) ;
 }
 
 QStringList svtplay_dl::horizontalHeaderLabels() const
@@ -391,10 +393,12 @@ QStringList svtplay_dl::horizontalHeaderLabels() const
 	return m ;
 }
 
-void svtplay_dl::setProxySetting( QStringList& e,const QString& s )
+engines::engine::baseEngine::optionsEnvironment svtplay_dl::setProxySetting( QStringList& e,const QString& s )
 {
 	e.append( "--proxy" ) ;
 	e.append( s ) ;
+
+	return {} ;
 }
 
 static bool _add( std::vector< engines::engine::baseEngine::mediaInfo >& s,const QString& e )
@@ -739,41 +743,44 @@ QString svtplay_dl::updateCmdPath( const QString& e )
 
 engines::metadata svtplay_dl::parseJsonDataFromGitHub( const QJsonDocument& doc )
 {
-	engines::metadata metadata ;
-
 	auto array = doc.array() ;
 
 	if( array.size() ){
 
-		QString url = [ & ](){
+		QString fileName ;
+		QString url ;
 
-			if( utility::platformIsWindows() ){
+		if( utility::platformIsWindows() ){
 
-				if( utility::platformIs32Bit() ){
+			if( utility::CPU().x86_32() ){
 
-					metadata.fileName = "svtplay-dl-win32.zip" ;
+				fileName = "svtplay-dl-win32.zip" ;
 
-					return "https://svtplay-dl.se/download/%1/svtplay-dl-win32.zip" ;
-				}else{
-					metadata.fileName = "svtplay-dl-amd64.zip" ;
-
-					return "https://svtplay-dl.se/download/%1/svtplay-dl-amd64.zip" ;
-				}
+				url = "https://svtplay-dl.se/download/%1/svtplay-dl-win32.zip" ;
 			}else{
-				metadata.fileName = "svtplay-dl" ;
+				fileName = "svtplay-dl-amd64.zip" ;
 
-				return "https://svtplay-dl.se/download/%1/svtplay-dl" ;
+				url = "https://svtplay-dl.se/download/%1/svtplay-dl-amd64.zip" ;
 			}
-		}() ;
+		}else{
+			fileName = "svtplay-dl" ;
 
-		auto obj = array[ 0 ].toObject() ;
+			url = "https://svtplay-dl.se/download/%1/svtplay-dl" ;
+		}
 
-		metadata.url = url.arg( obj.value( "name" ).toString() ) ;
+		QJsonObject obj ;
 
-		metadata.size = 0 ;
+		auto name = array[ 0 ].toObject().value( "name" ).toString() ;
+
+		obj.insert( "browser_download_url",url.arg( name ) ) ;
+		obj.insert( "name",fileName ) ;
+		obj.insert( "digest","" ) ;
+		obj.insert( "size",0 ) ;
+
+		return obj ;
+	}else{
+		return {} ;
 	}
-
-	return metadata ;
 }
 
 engines::engine::baseEngine::onlineVersion svtplay_dl::versionInfoFromGithub( const QByteArray& e )
