@@ -324,17 +324,33 @@ void networkAccess::failedToExtract( const networkAccess::cmdArgs& e,
 }
 
 void networkAccess::failedToRemove( const QString& name,
-				    const QString& src,
-				    const QString& err,
+				    const std::vector< engines::engine::baseEngine::removeFilesStatus >& err,
 				    int id ) const
 {
 	this->post( m_appName,utility::barLine(),id ) ;
 	this->post( name,QObject::tr( "Failed To Remove" ),id ) ;
-	this->post( name,"Src: " + src,id ) ;
-	this->post( name,"Err: " + err,id ) ;
+
+	for( const auto& it : err ){
+
+		this->post( name,"Src: " + it.src(),id ) ;
+		this->post( name,"Err: " + it.err(),id ) ;
+	}
+
 	this->post( m_appName,utility::barLine(),id ) ;
 }
 
+void networkAccess::failedToRemove( const QString& name,
+				    const QString& src,
+				    const QString& err,
+				    int id ) const
+{
+	std::vector< engines::engine::baseEngine::removeFilesStatus > s ;
+
+	s.emplace_back( src,err ) ;
+
+	this->failedToRemove( name,s,id ) ;
+}
+
 void networkAccess::failedToRename( const QString& name,
 				    const QString& src,
 				    const QString& dst,
@@ -822,19 +838,38 @@ void networkAccess::extractArchive( const engines::engine& engine,
 			this->post( engine.name(),m,str.id ) ;
 		}
 	}else{
-		auto m = utility::removeFile( str.exeBinPath ) ;
+		auto m = engine.removeFiles( { str.exeBinPath },QFileInfo( str.exeBinPath ).absolutePath() ) ;
 
-		if( !m.isEmpty() ){
+		if( m.size() ){
 
-			this->failedToRemove( engine.name(),str.exeBinPath,m,str.id ) ;
+			this->failedToRemove( engine.name(),m,str.id ) ;
 		}
 	}
 
-	auto cexe = utility::platformIsWindows() ? "bsdtar.exe" : "bsdtar" ;
+	QStringList extractorArgs ;
+	QString extractorExe ;
 
-	auto exe = m_ctx.Engines().findExecutable( cexe ) ;
+	if( utility::platformIsWindows() ){
 
-	if( exe.isEmpty() ){
+		extractorExe = m_ctx.Engines().findExecutable( "bsdtar.exe" ) ;
+		extractorArgs = QStringList{ "-x","-f",str.filePath,"-C",str.tempPath } ;
+	}else{
+		extractorExe = m_ctx.Engines().findExecutable( "bsdtar" ) ;
+
+		if( extractorExe.isEmpty() ){
+
+			extractorExe = m_ctx.Engines().findExecutable( "unzip" ) ;
+
+			if( !extractorExe.isEmpty() ){
+
+				extractorArgs = QStringList{ str.filePath,"-d",str.tempPath } ;
+			}
+		}else{
+			extractorArgs = QStringList{ "-x","-f",str.filePath,"-C",str.tempPath } ;
+		}
+	}
+
+	if( extractorExe.isEmpty() ){
 
 		auto m = QObject::tr( "Failed To Extract" ) ;
 
@@ -844,7 +879,7 @@ void networkAccess::extractArchive( const engines::engine& engine,
 
 				return QObject::tr( "Failed To Find \"bsdtar.exe\" Executable" ) ;
 			}else{
-				return QObject::tr( "Failed To Find \"bsdtar\" Executable" ) ;
+				return QObject::tr( "Failed To Find \"bsdtar\" or \"unzip\" Executable" ) ;
 			}
 		}() ;
 
@@ -857,7 +892,8 @@ void networkAccess::extractArchive( const engines::engine& engine,
 			str.iter.reportDone() ;
 		}
 	}else{
-		auto args = QStringList{ "-x","-f",str.filePath,"-C",str.tempPath } ;
+		const auto& exe = extractorExe ;
+		const auto& args = extractorArgs ;
 
 		str.exeArgs = { exe,args } ;
 
