@@ -1093,11 +1093,11 @@ Exampe 2: ${gateway}:8080</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Failed To Find &quot;bsdtar&quot; Executable</source>
+        <source>Skipping Checking Version Info For Engine &quot;%1&quot;</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Skipping Checking Version Info For Engine &quot;%1&quot;</source>
+        <source>Failed To Find &quot;bsdtar&quot; or &quot;unzip&quot; Executable</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
